serve

package module
v0.0.0-...-00f1b10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2020 License: MIT Imports: 10 Imported by: 0

README

Build Status Coverage Status Go Report Card

serve

serve is a simple cross-platform CLI tool to serve files over HTTP.

Install

You must have Go installed in order to build serve.

go get github.com/kszab0/serve

Usage

serve path/to/serve

Defaults to the current directory.

Usage of serve:
  -a string
        http address (default "localhost:9876")
  -q    use quiet mode - don't display logs

License

Authored by Kristóf Szabó and released under the MIT license.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CLI

func CLI(args []string) int

CLI runs the serve command line app and returns its exit status.

Types

This section is empty.

Directories

Path Synopsis
cmd
serve command

Jump to